@@ -4,10 +4,6 @@ When importing objects from modules, list each alphabetically.
 
 """
 
-__version__ = "0.1.0"
-__author__ = "Matthew Haines <hainesm6@gmail.com>"
-__all__ = []
-
 from .main import BasicAssembly, BasicLinker, BasicPart, BasicUTRRBSLinker, seqrec2part
 from .bsb_io import (
     export_sequences_to_file,
@@ -21,7 +17,12 @@ from .parts_linkers import (
     BASIC_PROMOTER_PARTS,
     BASIC_SEVA_PARTS,
 )
-from .cam import BasicBuild, BuildDecoder, BuildEncoder, new_part_resuspension
-
-from .functions import export_echo_assembly
-from .functions import pdf_instructions
+from .cam import (
+    BasicBuild,
+    BuildDecoder,
+    BuildEncoder,
+    build_digest,
+    new_part_resuspension,
+    export_echo_assembly,
+    pdf_instructions,
+)
