@@ -1,6 +1,6 @@
 """The parts_linkers subpackage houses a collection of modules describing parts
 and/or linkers."""
 
-from .basic_linkers import BASIC_BIOLEGIO_LINKERS
+from .biolegio_linkers import BASIC_BIOLEGIO_LINKERS
 from .basic_parts import BASIC_CDS_PARTS, BASIC_SEVA_PARTS, BASIC_PROMOTER_PARTS
 from .main import *
